diff --git a/accounts/abi/bind/auth.go b/accounts/abi/bind/auth.go
index ad482abc02355285f60c65c4e3b6db504cc364a1..5d5ad0034c86b496aee14547c39dd91988cc5f1e 100644
--- a/accounts/abi/bind/auth.go
+++ b/accounts/abi/bind/auth.go
@@ -43,9 +43,9 @@ func NewTransactor(keyin io.Reader, passphrase string) (*TransactOpts, error) {
 	return NewKeyedTransactor(key.PrivateKey), nil
 }
 
 // NewTransactor is a utility method to easily create a transaction signer from
 // an decrypted key from a keystore
-func NewTransactorFromKeyStore(keystore *keystore.KeyStore, account accounts.Account) (*TransactOpts, error) {
+func NewKeyStoreTransactor(keystore *keystore.KeyStore, account accounts.Account) (*TransactOpts, error) {
 	return &TransactOpts{
 		From: account.Address,
 		Signer: func(signer types.Signer, address common.Address, tx *types.Transaction) (*types.Transaction, error) {
@@ -43,9 +43,9 @@ func NewTransactor(keyin io.Reader, passphrase string) (*TransactOpts, error) {
 }
 
-// NewTransactor is a utility method to easily create a transaction signer from
+// NewKeystoreTransactor is a utility method to easily create a transaction signer from
 // an decrypted key from a keystore